# Search Google Address

## Usage
Google Search API with caching for repeated search.

## Example Code
```python
from search_addr import SearchAddressGoogleAPI

search_lib = SearchAddressGoogleAPI(key="YOUR_GOOGLE_SERVER_KEY")
search_lib.search_google("569KA/104 Shen Nagar, Alambagh, Lucknow, Uttar Pradesh, 226005")
```
